==> haskell-regex-tdfa-1.2.2-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-tdfa.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-tdfa
version: 1.2.2
id: regex-tdfa-1.2.2-LXrPID2GWRYz5rkILVGL8
key: regex-tdfa-1.2.2-LXrPID2GWRYz5rkILVGL8
license: BSD3
copyright: Copyright (c) 2007, Christopher Kuklewicz
maintainer: Artyom <yom@artyom.me>, Christopher Kuklewicz <TextRegexLazy@personal.mightyreason.com>
stability: Seems to work, but not POSIX yet
homepage: https://github.com/ChrisKuklewicz/regex-tdfa
synopsis: Replaces/Enhances Text.Regex
description:
    A new all Haskell "tagged" DFA regex engine, inspired by libtre
category: Text
author: Christopher Kuklewicz
exposed: True
indefinite: False
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.NewDFA.Tester Text.Regex.TDFA.NewDFA.Uncons
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA
hidden-modules: Paths_regex_tdfa
abi: e1619b316a6b2dcb983f330c43208f5f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-tdfa-1.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-tdfa-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/regex-tdfa-1.2.2
hs-libraries: HSregex-tdfa-1.2.2-LXrPID2GWRYz5rkILVGL8
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    ghc-prim-0.5.1.1 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    parsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1
    regex-base-0.93.2-rcKBNTI69reeBx0eaPBC
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             parsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1=893424ff0bd1ccfdf429c25df7ce2aa4
             regex-base-0.93.2-rcKBNTI69reeBx0eaPBC=d7d8f12e28b86f8254a2a5665d808c04
haddock-interfaces: /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-tdfa-1.2.2-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-tdfa.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-tdfa
version: 1.2.2
id: regex-tdfa-1.2.2-JGrSDGN9OzgIG6BjzD8Db2
key: regex-tdfa-1.2.2-JGrSDGN9OzgIG6BjzD8Db2
license: BSD3
copyright: Copyright (c) 2007, Christopher Kuklewicz
maintainer: Artyom <yom@artyom.me>, Christopher Kuklewicz <TextRegexLazy@personal.mightyreason.com>
stability: Seems to work, but not POSIX yet
homepage: https://github.com/ChrisKuklewicz/regex-tdfa
synopsis: Replaces/Enhances Text.Regex
description:
    A new all Haskell "tagged" DFA regex engine, inspired by libtre
category: Text
author: Christopher Kuklewicz
exposed: True
indefinite: False
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.NewDFA.Tester Text.Regex.TDFA.NewDFA.Uncons
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA
hidden-modules: Paths_regex_tdfa
abi: 1f7384d261dd3860221965b2d2274d30
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-tdfa-1.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-tdfa-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/regex-tdfa-1.2.2
hs-libraries: HSregex-tdfa-1.2.2-JGrSDGN9OzgIG6BjzD8Db2
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    ghc-prim-0.5.1.1 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7
    regex-base-0.93.2-rcKBNTI69reeBx0eaPBC
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7=5b8a6db8c81629fde3a12212030372e3
             regex-base-0.93.2-rcKBNTI69reeBx0eaPBC=d7d8f12e28b86f8254a2a5665d808c04
haddock-interfaces: /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
